@@ -1,13 +1,15 @@
 import numpy as np
 
 
+import pykin.utils.transform_utils as t_utils
+import pykin.utils.kin_utils as k_utils
+import pykin.kinematics.jacobian as jac
+
 from pykin.planners.planner import Planner
 from pykin.utils.error_utils import OriValueError, CollisionError
 from pykin.utils.kin_utils import ShellColors as sc
 from pykin.utils.log_utils import create_logger
-import pykin.utils.transform_utils as t_utils
-import pykin.utils.kin_utils as k_utils
-import pykin.kinematics.jacobian as jac
+from pykin.utils.transform_utils import get_linear_interpoation, get_quaternion_slerp
 
 logger = create_logger('Cartesian Planner', "debug",)
 
@@ -27,8 +29,11 @@ class CartesianPlanner(Planner):
         dimension=7,
         waypoint_type="Linear"
     ):
-        super(CartesianPlanner, self).__init__(robot, self_collision_manager, dimension)
-        self.obstacle_collision_manager = obstacle_collision_manager
+        super(CartesianPlanner, self).__init__(
+            robot, 
+            self_collision_manager, 
+            obstacle_collision_manager,
+            dimension)
         self.n_step = n_step
         self.waypoint_type = waypoint_type
         self.eef_name = self.robot.eef_name
@@ -59,7 +64,7 @@ class CartesianPlanner(Planner):
         self._cur_pose = self.robot.get_eef_pose(init_fk)
 
         if waypoints is None:
-            waypoints = self.genearte_waypoints(is_slerp)
+            waypoints = self.generate_waypoints(is_slerp)
 
         paths, target_posistions = self._compute_path_and_target_pose(waypoints, resolution, damping, epsilon, pos_sensitivity)
         
@@ -75,9 +80,9 @@ class CartesianPlanner(Planner):
     ):
         cnt = 0
         total_cnt = 10
-
         while True:
             cnt += 1
+            collision_pose = {}
             cur_fk = self.robot.kin.forward_kinematics(self.robot.desired_frames, self._cur_qpos)
 
             current_transform = cur_fk[self.eef_name].h_mat
@@ -98,6 +103,7 @@ class CartesianPlanner(Planner):
                 collision_free = self.collision_free(self._cur_qpos, visible_name=False)
 
                 if not collision_free:
+                    collision_pose[step] = np.round(target_transform[:3,3],3)
                     continue
 
                 if not self._check_q_in_limits(self._cur_qpos):
@@ -111,7 +117,14 @@ class CartesianPlanner(Planner):
                     target_posistions.append(pos)
 
             err = t_utils.compute_pose_error(self._goal_pose[:3], cur_fk[self.eef_name].pos)
-
+            
+            if collision_pose.keys():
+                logger.error(f"Failed Generate Path.. Collision may occur.")
+                # logger.warning(f"Collision Position : {collision_pose.values()}")
+                for pose in collision_pose.values():
+                    logger.warning(f"Collision Position : {pose}")
+                raise CollisionError("Conflict confirmed. Check the object position!")
+                
             if err < pos_sensitivity:
                 logger.info(f"Generate Path Successfully!! Error is {err:6f}")
                 break
@@ -141,31 +154,33 @@ class CartesianPlanner(Planner):
             names(set of 2-tup): The set of pairwise collisions. 
         """
 
-        if self.self_collision_manager is None:
+        if self.self_c_manager is None:
             return True
             
         transformations = self._get_transformations(new_q)
         for link, transformations in transformations.items():
-            if link in self.self_collision_manager._objs:
+           if link in self.self_c_manager._objs:
                 transform = transformations.h_mat
-                self.self_collision_manager.set_transform(name=link, transform=transform)
-        is_collision = self.self_collision_manager.in_collision_internal(return_names=False, return_data=False)
+                A2B = np.dot(transform, self.robot.links[link].visual.offset.h_mat)
+                self.self_c_manager.set_transform(name=link, transform=A2B)
+        is_self_collision = self.self_c_manager.in_collision_internal(return_names=False, return_data=False)
+        is_obstacle_collision = self.self_c_manager.in_collision_other(other_manager=self.obstacle_c_manager, return_names=False)
 
         name = None
         if visible_name:
-            if is_collision:
+            if is_self_collision:
                 return False, name
             return True, name
 
-        if is_collision:
+        if is_self_collision or is_obstacle_collision:
             return False
         return True
 
     # TODO
     # generate cubic, circular waypoints
-    def genearte_waypoints(self, is_slerp):
+    def generate_waypoints(self, is_slerp):
         if self.waypoint_type == "Linear":
-            waypoints = [path for path in self._get_linear_path(is_slerp)]
+            waypoints = [path for path in self._get_linear_path(self._cur_pose, self._goal_pose, is_slerp)]
         if self.waypoint_type == "Cubic":
             pass
         if self.waypoint_type == "Circular":
@@ -193,13 +208,13 @@ class CartesianPlanner(Planner):
 
         return ret
 
-    def _get_linear_path(self, is_slerp):
+    def _get_linear_path(self, init_pose, goal_pose, is_slerp):
         for step in range(1, self.n_step + 1):
             delta_t = step / self.n_step
-            pos = t_utils.get_linear_interpoation(self._cur_pose[:3], self._goal_pose[:3], delta_t)
-            ori = self._cur_pose[3:]
+            pos = get_linear_interpoation(init_pose[:3], goal_pose[:3], delta_t)
+            ori = init_pose[3:]
             if is_slerp:
-                ori = t_utils.get_quaternion_slerp(self._cur_pose[3:], self._goal_pose[3:], delta_t)
+                ori = get_quaternion_slerp(init_pose[3:], goal_pose[3:], delta_t)
 
             yield (pos, ori)
 
@@ -207,12 +222,4 @@ class CartesianPlanner(Planner):
         pass
 
     def _get_cicular_path(self):
-        pass
-
-    # @property
-    # def dimension(self):
-    #     return self._dimension
-
-    # @dimension.setter
-    # def dimension(self, dimesion):
-    #     self._dimension = dimesion
\ No newline at end of file
+        pass
\ No newline at end of file
