@@ -5,7 +5,8 @@ from pykin.planners.planner import Planner
 from pykin.planners.tree import Tree
 from pykin.utils.log_utils import create_logger
 from pykin.utils.kin_utils import ShellColors as sc
-from pykin.utils.transform_utils import compute_pose_error
+from pykin.utils.transform_utils import get_linear_interpoation
+
 logger = create_logger('RRT Star Planner', "debug")
 
 class RRTStarPlanner(Planner):
@@ -31,10 +32,13 @@ class RRTStarPlanner(Planner):
         max_iter=3000,
         gamma_RRT_star=300, # At least gamma_RRT > delta_distance,
         dimension=7,
+        n_step=10
     ):
-        super(RRTStarPlanner, self).__init__(robot, self_collision_manager, dimension)
-
-        self.obstacle_c_manager=obstacle_collision_manager
+        super(RRTStarPlanner, self).__init__(
+            robot, self_collision_manager, 
+            obstacle_collision_manager,
+            dimension
+        )
         self.delta_dis = delta_distance
         self.epsilon = epsilon
         self.max_iter = max_iter
@@ -47,6 +51,7 @@ class RRTStarPlanner(Planner):
 
         self.arm = None
         self.dimension = dimension
+        self.n_step = n_step
         self.eef_name = self.robot.eef_name
 
         super()._setup_q_limits()
@@ -119,6 +124,7 @@ class RRTStarPlanner(Planner):
             if cnt > total_cnt:
                 logger.error(f"Failed Generate Path.. The number of retries of {cnt} exceeded")
                 break
+
             logger.error(f"Failed Generate Path..")
             print(f"{sc.BOLD}Retry Generate Path, the number of retries is {cnt}/{total_cnt} {sc.ENDC}\n")
         
@@ -128,7 +134,14 @@ class RRTStarPlanner(Planner):
                 if step % round(1/resolution) == 0 or step == len(path)-1:
                     result_path.append(joint)
 
-        return result_path
+            interpolate_path = []
+            interpolate_paths = []
+            
+            for i in range(len(result_path)-1):
+                interpolate_path = [path.tolist() for path in self._get_linear_path(result_path[i], result_path[i+1])]
+                interpolate_paths.extend(interpolate_path)
+
+        return result_path, interpolate_paths
 
     def random_state(self):
         """
@@ -194,15 +207,19 @@ class RRTStarPlanner(Planner):
             names(set of 2-tup): The set of pairwise collisions. 
         """
  
+        if self.self_c_manager is None:
+            return True
+
         transformations = self._get_transformations(new_q)
+
         for link, transformations in transformations.items():
-            if "pedestal" in link:
-                continue
-            if link in self.self_collision_manager._objs:
+            if link in self.self_c_manager._objs:
                 transform = transformations.h_mat
-                self.self_collision_manager.set_transform(name=link, transform=transform)
-        is_self_collision = self.self_collision_manager.in_collision_internal(return_names=False, return_data=False)
-        is_obstacle_collision = self.self_collision_manager.in_collision_other(other_manager=self.obstacle_c_manager, return_names=False)
+                A2B = np.dot(transform, self.robot.links[link].visual.offset.h_mat)
+                self.self_c_manager.set_transform(name=link, transform=A2B)
+        
+        is_self_collision = self.self_c_manager.in_collision_internal(return_names=False, return_data=False)
+        is_obstacle_collision = self.self_c_manager.in_collision_other(other_manager=self.obstacle_c_manager, return_names=False)  
 
         name = None
         if visible_name:
@@ -365,3 +382,9 @@ class RRTStarPlanner(Planner):
             goal_node = self.T.vertices[edge[1]]
             vertices.append((from_node, goal_node))
         return vertices
+
+    def _get_linear_path(self, init_pose, goal_pose):
+        for step in range(1, self.n_step + 1):
+            delta_t = step / self.n_step
+            qpos = get_linear_interpoation(init_pose, goal_pose, delta_t)
+            yield qpos
\ No newline at end of file
